A simple text-based game in the style of 80s adventure games, in which you play
a hungry corgi.

How to run:

```
OPENAI_API_KEY=<your key> python application.py
```

![State Machine](statemachine.png)
